
// wav2ambe: convert wav-files to .ambe-files
// usage wav2ambe infile.wav outfile.ambe
// this program requires a DVdongle to do AMBE encoding, connected to
// a USB-port
// this program requires the sndfile-libraries to import wav-files
// see http://www.mega-nerd.com/libsndfile/

// The goal is to use this program to produce audio announcements on
// DSTAR repeaters by stitching pre-encoded AMBE files together

// copyright (C) 2010 Kristoff Bonne ON1ARF
/*
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

//  release info:
// 17 okt. 2010: version 0.0.1. Initial release


// global DEFINEs
#define BUFFERSIZE 320

// global data-structure. This is used to communicate between threads
// The global data is initialy filled in by the main part of the process
// and then send to the child-processes as parameter during startup

// data that does not changed (like udpsd) is passed as normal data
// data that does change (like p_pingbuffer_low and _high) is passed as pointer

// structure of PCM-frame send and received from/to dongle
typedef struct {
int donglefd;

int *p_allpacketsend;
int *p_welive_serialreceive;

int fileformat;

} globaldatastr; // global data structure



// data-structures for communication between the threads
int datatosend;
int datasendready;
int allpacketsend;
int donglefd;

int outputfileformat;

int serialsendcount=0;

int welive_serialreceive;

char * fname_out=NULL;

// packets sent to dongle:
// starts with two bytes containing length of packet and packet type

// command to dongle: request name
const unsigned char request_name[] = {0x04, 0x20, 0x01, 0x00};
// command to dongle: start
const unsigned char command_start[] = {0x05, 0x00, 0x18, 0x00, 0x01};
// command to dongle: stop
const unsigned char command_stop[] = {0x05, 0x00, 0x18, 0x00, 0x02};

// ambe-packet: does not contain any actual ambe-data (last 24 bytes) but contains configuration-setting for ambe-encoder
// see http://www.moetronix.com/dvdongle and http://www.dvsinc.com/products/a2020.htm for more info
const unsigned char ambe[] = {0x32, 0xA0,0xEC, 0x13, 0x00, 0x00, 0x30, 0x10, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x48, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x04, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};


// End of global data



// start data structure configuration

// structure of PCM-frame send and received from/to dongle
struct {
	char buffsize1;
	char buffsize2;
	char pcm[BUFFERSIZE];
} pcmbuffer;


// end data structure configuration
