#! /usr/bin/perl



## ambe2dvtool: converts ambe-files to DSTAR .dvtool files
## usage ambe2dvtool outfile.dvtool infile1.ambe [ infile2.ambe ... ]

## The goal is to use this program to produce audio announcements on
## DSTAR repeaters by stitching pre-encoded AMBE files together

## copyright (C) 2010 Kristoff Bonne ON1ARF
##
##   This program is free software; you can redistribute it and/or modify
##   it under the terms of the GNU General Public License as published by
##   the Free Software Foundation; either version 2 of the License, or
##   (at your option) any later version.
##
##   This program is distributed in the hope that it will be useful,
##   but WITHOUT ANY WARRANTY; without even the implied warranty of
##   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##   GNU General Public License for more details.
##
##   You should have received a copy of the GNU General Public License
##   along with this program; if not, write to the Free Software
##   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
##

##  release info:
## 17 okt. 2010: version 0.0.1. Initial release in C
## 22 okt. 2010: version 0.0.2. Initial release in perl



# 1st parameter: output filename (.dvtool file)
# 2nd and following parameters: input files (.ambe files)
$fout=shift;
$fin=shift;


if (($fout eq "") || ($fin eq "")) {
	print STDERR "Error: need at least 2 parameters:\n";
	print STDERR "syntax: ambe2dvtool outfile.dvtool infile.ambe \[infile.ambe ... \]\n";
	exit;
}; # end if


# datastructures:
# header file of .dvtool file: consists of file-header (10 bytes: "DVTOOL" + 4 bytes length) + 1 start-frame (58 bytes)

@header = (0x44,0x56,0x54,0x4f,0x4f,0x4c,0x00,0x00,0x00,0x00,0x38,0x00,0x44,0x53,0x56,0x54,0x10,0x00,0x81,0x00,0x20,0x00,0x01,0x02,0xe8,0x4f,0x80,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xff,0xff);

# dataline of .dvtool file.
# important fields:
# octets 0 to 1: length (LSB)
# octets 2 to 5: "DVT "
# octet 17: line counter (goes from 0 to 20)
# octets 18 to 25: ambe data

@line = (0x1b,0x00,0x44,0x53,0x56,0x54,0x20,0x00,0x81,0x00,0x20,0x00,0x01,0x02,0xe8,0x4f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x55,0x2d,0x16);

# open files
open (FILEOUT,">$fout");

binmode FILEOUT;

# write header to outfile
$headerpacket=pack("CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC",@header);
print FILEOUT $headerpacket;

# init some vars
$packetcount=0;
$packetcounttotal=1;
$filecount=0;

# $fin is the name of input filename

while ($fin ne "") {

	# open input file
	open (FILEIN,"<$fin");
	binmode FILEIN;

	$filecount++;

	# read file, line per line
	inline: while (<FILEIN>) {

		# remove comment-lines (everything beginning with '#')
		if ($_ =~ /^#/) {
			next inline;
		} # end if;

		# split line in words: ambe-data in in hexstring (3th word)
		($part1,$part2,$hexstring,$dummy)=split(" ",$_,4);

		# convert string of hex-characters to characters:
		# shamelessly stolen from the internet: see
		# http://icfun.blogspot.com/2009/05/perl-convert-hex-string-into-character.html
		$hexstring =~ s/([a-fA-F0-9][a-fA-F0-9])/chr(hex($1))/eg;

		# insert 9 bytes of hexstring into line
		for ($loop=0;$loop<9;$loop++) {
			$line[$loop+17]=ord(substr($hexstring,$loop,1));
		};  # end for


		# 16th byte of line is line-counter
		$line[16]=$packetcount;

		# save packet to file
		$linepacket=pack("CCCCCCCCCCCCCCCCCCCCCCCCCCCCC",@line);
		print FILEOUT $linepacket;


		# before reading next frame, increase packetcount
		$packetcount++;
		$packetcounttotal++;

		if ($packetcount > 20) {
			$packetcount=0;
		}; # end if
	}; # end while

	# close input file
	close FILEIN;


	# get name of next file
	$fin=shift;

}; # end while (filename input file)


# all input files read: write end-frame

# end-frame, ambe-data is all 0
for ($loop=17;$loop<26;$loop++) {
	$line[$loop]=0;
}; # end for

# add 0x40  to packetcount to set "last frame" bit
$packetcount += 0x40;
$line[16]=$packetcount;

# save packet to file
$linepacket=pack("CCCCCCCCCCCCCCCCCCCCCCCCCCCCC",@line);
print FILEOUT $linepacket;



# now rewind to beginning of file
# write number-of-frames counter (octets 6 to 9)
seek(FILEOUT,6,SEEK_SET);

$linepacket=pack("N",($packetcounttotal));
print FILEOUT $linepacket;

close (FILEOUT);

print "done: $packetcounttotal frames writen from $filecount input file(s). This includes 1 header-frame\n";

