#! /usr/bin/perl


## dvtconc: concatenate .dvtool files
## usage dvtconc outfile.dvtool infile1.dvtool [ infile2.dvtool ... ]

## The goal is to use this program to produce audio announcements on
## DSTAR repeaters by stitching pre-encoded AMBE files in .dvtool
##	format together

## copyright (C) 2010 Kristoff Bonne ON1ARF
##
##   This program is free software; you can redistribute it and/or modify
##   it under the terms of the GNU General Public License as published by
##   the Free Software Foundation; either version 2 of the License, or
##   (at your option) any later version.
##
##   This program is distributed in the hope that it will be useful,
##   but WITHOUT ANY WARRANTY; without even the implied warranty of
##   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##   GNU General Public License for more details.
##
##   You should have received a copy of the GNU General Public License
##   along with this program; if not, write to the Free Software
##   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
##

##  release info:
## 26 sep. 2010: version 0.0.1. Initial release in C
## 22 okt. 2010: version 0.0.2. Initial release in perl



# 1st parameter: output filename 
# 2nd and following parameters: input files
$fout=shift;
$fin=shift;


if (($fout eq "") || ($fin eq "")) {
	print STDERR "Error: need at least 2 parameters:\n";
	print STDERR "syntax: ambe2dvtool outfile.dvtool infile.dvtool \[infile.dvtool ... \]\n";
	exit;
}; # end if


# datastructures:
# header file of .dvtool file: consists of file-header (10 bytes: "DVTOOL" + 4 bytes length) + 1 start-frame (58 bytes)

@header = (0x44,0x56,0x54,0x4f,0x4f,0x4c,0x00,0x00,0x00,0x00,0x38,0x00,0x44,0x53,0x56,0x54,0x10,0x00,0x81,0x00,0x20,0x00,0x01,0x02,0xe8,0x4f,0x80,0x00,0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0xff,0xff);

# dataline of .dvtool file.
# important fields:
# octets 0 to 1: length (LSB)
# octets 2 to 5: "DVT "
# octet 17: line counter (goes from 0 to 20)
# octets 18 to 25: ambe data

@line = (0x1b,0x00,0x44,0x53,0x56,0x54,0x20,0x00,0x81,0x00,0x20,0x00,0x01,0x02,0xe8,0x4f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x55,0x2d,0x16);
$linepacket=pack("CCCCCCCCCCCCCCCCCCCCCCCCCCCCC",@line);

# open files
open (FILEOUT,">$fout");

binmode FILEOUT;

# write header to outfile
$headerpacket=pack("CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC",@header);
print FILEOUT $headerpacket;

$packetcounttotal=1;
$filecount=0;
$endframefound=0;

# $fin is the name of input filename

while ($fin ne "") {

	# open input file
	open (FILEIN,"<$fin");
	binmode FILEIN;

	$packetcount=0;
	$filecount++;

	# read file header (10 bytes, no used)
	read(FILEIN,$dummy,10);

	# read 2 bytes (lenght of next frame)
	read(FILEIN,$sizetxt,2);

	# not end of file?
	while ($sizetxt ne "") {
		($size,$dummy)=unpack("v",$sizetxt);

		# read rest of frame
		read(FILEIN,$packetin,$size);

		# .dvtool file format (packetin string data-structure)
		# octets 0 to 3: "DSVT"
		# octet 14 : sequence (wrapps around at 20, last frame has
		# 						sequence + 0x40)
		# octets 15 to 23: 9 bytes ambe data
		# octets 24 to 26: unused (slow speed data?)
		# note: linepacket includes the 2 bytes length and "packetin" does not
		# so for linepacket, always add 2

		# we are only interested in data-frames:
		# 5th based is 0x20 and length is 29 bytes
		# also discard "end"-frames (sequence > 0x40)

		if (($size == 27) && (ord(substr($packetin,4,1)) == 0x20 ) && 
			(ord(substr($packetin,14,1)) < 0x40)) {

			# copy 9 bytes of ambe-data from input packet into our
			# "line" structure
			# see comment above for data structure
			substr($linepacket,17,9,substr($packetin,15,9));

			# 15th octet (beginning with 0) of line is line-counter
			substr($linepacket,16,1,chr($packetcount));

			# save packet to file
			print FILEOUT $linepacket;


			# before reading next frame, increase packetcount
			$packetcount++;
			$packetcounttotal++;

			if ($packetcount > 20) {
				$packetcount=0;
			}; # end if

		}; # end if

		# read next packet size
		read(FILEIN,$sizetxt,2);

	}; # end while

	# close input file
	close FILEIN;


	# get name of next file
	$fin=shift;

}; # end while (filename input file)


# all input files read: write end-frame

# end-frame, ambe-data is all 0
for ($loop=17;$loop<26;$loop++) {
	$line[$loop]=0;
}; # end for

# add 0x40  to packetcount to set "last frame" bit
$packetcount += 0x40;
$line[16]=$packetcount;

# save packet to file
$linepacket=pack("CCCCCCCCCCCCCCCCCCCCCCCCCCCCC",@line);
print FILEOUT $linepacket;



# now rewind to beginning of file
# write number-of-frames counter (octets 6 to 9)
seek(FILEOUT,6,SEEK_SET);

$linepacket=pack("N",($packetcounttotal));
print FILEOUT $linepacket;

close (FILEOUT);

print "done: $packetcounttotal frames written from $filecount input file(s). This includes 1 header-frame\n";

